Flask Chat
==========

Flask implementation of chat from `gevent-socketio <https://github.com/hartwork/gevent-socketio>`_ examples.

To Run this example, before you start you need to navigate to this folder and run:

	python init_db.py

Then to run use:

	python run.py

Open your browser to:

	localhost:5000


And everything should be working now.  If you want to reset just stop the server, delete the file: /tmp/chat.db, and re-run init_db.py



